@@ -9,12 +9,11 @@ if [ "$#" -lt 1 ]; then
 fi
 
 APP_NAME="$1"
-MODE="${2:-}"  # Optional second argument for dark/light mode
+MODE="${2:-}" # Optional second argument for dark/light mode
 
 # --- Apply theme based on the application name ---
 case "$APP_NAME" in
 kitty)
-    echo "🎨 Applying 'noctalia' theme to kitty..."
     KITTY_CONF="$HOME/.config/kitty/kitty.conf"
     if [ -w "$KITTY_CONF" ]; then
         kitty +kitten themes --reload-in=all noctalia
@@ -24,14 +23,11 @@ kitty)
     ;;
 
 ghostty)
-    echo "🎨 Applying 'noctalia' theme to ghostty..."
     CONFIG_FILE="$HOME/.config/ghostty/config"
     # Check if the config file exists before trying to modify it.
     if [ -f "$CONFIG_FILE" ]; then
         # Check if theme is already set to noctalia
-        if grep -q "^theme = noctalia" "$CONFIG_FILE"; then
-            echo "Theme already set to noctalia, skipping modification."
-        else
+        if ! grep -q "^theme = noctalia" "$CONFIG_FILE"; then
             # Remove any existing theme include line to prevent duplicates.
             sed -i '/theme/d' "$CONFIG_FILE"
             # Add the new theme include line to the end of the file.
@@ -46,12 +42,10 @@ ghostty)
     ;;
 
 foot)
-    echo "🎨 Applying 'noctalia' theme to foot..."
     CONFIG_FILE="$HOME/.config/foot/foot.ini"
 
     # Check if the config file exists, create it if it doesn't.
     if [ ! -f "$CONFIG_FILE" ]; then
-        echo "Config file not found, creating $CONFIG_FILE..."
         # Create the config directory if it doesn't exist
         mkdir -p "$(dirname "$CONFIG_FILE")"
         # Create the config file with the noctalia theme
@@ -59,12 +53,9 @@ foot)
 [main]
 include=~/.config/foot/themes/noctalia
 EOF
-        echo "Created new config file with noctalia theme."
     else
         # Check if theme is already set to noctalia
-        if grep -q "include.*noctalia" "$CONFIG_FILE"; then
-            echo "Theme already set to noctalia, skipping modification."
-        else
+        if ! grep -q "include.*noctalia" "$CONFIG_FILE"; then
             # Remove any existing theme include line to prevent duplicates.
             sed -i '/include=.*themes/d' "$CONFIG_FILE"
             if grep -q '^\[main\]' "$CONFIG_FILE"; then
@@ -79,38 +70,35 @@ EOF
     ;;
 
 alacritty)
-    echo "🎨 Applying 'noctalia' theme to alacritty..."
     CONFIG_FILE="$HOME/.config/alacritty/alacritty.toml"
 
-    # Check if the config file exists.
-    if [ -f "$CONFIG_FILE" ]; then
-        # Check if theme is already imported
-        if grep -q 'import = \[.*"themes/noctalia.toml".*\]' "$CONFIG_FILE"; then
-            echo "Theme already set to noctalia, skipping modification."
-        else
+    # Check if the config file exists, create it if it doesn't.
+    if [ ! -f "$CONFIG_FILE" ]; then
+        # Create the config directory if it doesn't exist
+        mkdir -p "$(dirname "$CONFIG_FILE")"
+        # Create the config file with the noctalia theme import
+        cat >"$CONFIG_FILE" <<'EOF'
+[general]
+import = [
+    "~/.config/alacritty/themes/noctalia.toml"
+]
+EOF
+    else
+        # Check if theme is already imported (checking for the exact path)
+        if ! grep -q '"~/.config/alacritty/themes/noctalia.toml"' "$CONFIG_FILE"; then
             # Check if [general] section exists
             if grep -q '^\[general\]' "$CONFIG_FILE"; then
-                # Check if import line exists under [general]
-                if sed -n '/^\[general\]/,/^\[/p' "$CONFIG_FILE" | grep -q '^import = \['; then
-                    # Replace existing import line with noctalia theme
-                    sed -i '/^\[general\]/,/^\[/{s|^import = \[.*\]|import = ["themes/noctalia.toml"]|}' "$CONFIG_FILE"
-                else
-                    # Add import line after [general] section
-                    sed -i '/^\[general\]/a import = ["themes/noctalia.toml"]' "$CONFIG_FILE"
-                fi
+                # Add import line after [general] section header
+                sed -i '/^\[general\]/a import = ["~/.config/alacritty/themes/noctalia.toml"]' "$CONFIG_FILE"
             else
                 # Create [general] section with import at the beginning of the file
-                sed -i '1i [general]\nimport = ["themes/noctalia.toml"]\n' "$CONFIG_FILE"
+                sed -i '1i [general]\nimport = ["~/.config/alacritty/themes/noctalia.toml"]\n' "$CONFIG_FILE"
             fi
         fi
-    else
-        echo "Error: alacritty config file not found at $CONFIG_FILE" >&2
-        exit 1
     fi
     ;;
 
 wezterm)
-    echo "🎨 Applying 'noctalia' theme to wezterm..."
     CONFIG_FILE="$HOME/.config/wezterm/wezterm.lua"
     WEZTERM_SCHEME_LINE='config.color_scheme = "Noctalia"'
 
@@ -118,9 +106,7 @@ wezterm)
     if [ -f "$CONFIG_FILE" ]; then
 
         # Check if theme is already set to Noctalia (matches 'Noctalia' or "Noctalia")
-        if grep -q "^\s*config\.color_scheme\s*=\s*['\"]Noctalia['\"]\s*" "$CONFIG_FILE"; then
-            echo "Theme already set to Noctalia, skipping modification."
-        else
+        if ! grep -q "^\s*config\.color_scheme\s*=\s*['\"]Noctalia['\"]\s*" "$CONFIG_FILE"; then
             # Not set to Noctalia. Check if *any* color_scheme line exists.
             if grep -q '^\s*config\.color_scheme\s*=' "$CONFIG_FILE"; then
                 # It exists, so we replace it with our desired line.
@@ -147,24 +133,19 @@ wezterm)
     ;;
 
 fuzzel)
-    echo "🎨 Applying 'noctalia' theme to fuzzel..."
     CONFIG_FILE="$HOME/.config/fuzzel/fuzzel.ini"
 
     # Check if the config file exists, create it if it doesn't.
     if [ ! -f "$CONFIG_FILE" ]; then
-        echo "Config file not found, creating $CONFIG_FILE..."
         # Create the config directory if it doesn't exist
         mkdir -p "$(dirname "$CONFIG_FILE")"
         # Create the config file with the noctalia theme
         cat >"$CONFIG_FILE" <<'EOF'
 include=~/.config/fuzzel/themes/noctalia
 EOF
-        echo "Created new config file with noctalia theme."
     else
         # Check if theme is already set to noctalia
-        if grep -q "include=~/.config/fuzzel/themes/noctalia" "$CONFIG_FILE"; then
-            echo "Theme already set to noctalia, skipping modification."
-        else
+        if ! grep -q "include=~/.config/fuzzel/themes/noctalia" "$CONFIG_FILE"; then
             # Remove any existing theme include line.
             sed -i '/themes/d' "$CONFIG_FILE"
             # Add the new theme include line.
@@ -174,15 +155,12 @@ EOF
     ;;
 
 walker)
-    echo "🎨 Applying 'noctalia' theme to walker..."
     CONFIG_FILE="$HOME/.config/walker/config.toml"
 
     # Check if the config file exists.
     if [ -f "$CONFIG_FILE" ]; then
         # Check if theme is already set to noctalia
-        if grep -q '^theme = "noctalia"' "$CONFIG_FILE"; then
-            echo "Theme already set to noctalia, skipping modification."
-        else
+        if ! grep -q '^theme = "noctalia"' "$CONFIG_FILE"; then
             # Check if a theme line exists and replace it, otherwise append
             if grep -q '^theme = ' "$CONFIG_FILE"; then
                 sed -i 's/^theme = .*/theme = "noctalia"/' "$CONFIG_FILE"
@@ -197,17 +175,14 @@ walker)
     ;;
 
 vicinae)
-    echo "🎨 Applying noctalia theme to vicinae..."
     # Apply the theme
     vicinae theme set noctalia
     ;;
 
 pywalfox)
-    echo "🎨 Updating pywalfox themes..."
     # Set dark/light mode first if MODE is specified
     if [ -n "$MODE" ]; then
         if [ "$MODE" = "dark" ] || [ "$MODE" = "light" ]; then
-            echo "Setting pywalfox to $MODE mode..."
             pywalfox "$MODE"
         else
             echo "Warning: Invalid mode '$MODE'. Expected 'dark' or 'light'. Skipping mode switch." >&2
@@ -218,7 +193,6 @@ pywalfox)
     ;;
 
 cava)
-    echo "🎨 Applying 'noctalia' theme to cava..."
     CONFIG_FILE="$HOME/.config/cava/config"
     THEME_MODIFIED=false
 
@@ -226,11 +200,8 @@ cava)
     if [ -f "$CONFIG_FILE" ]; then
         # Check if [color] section exists
         if grep -q '^\[color\]' "$CONFIG_FILE"; then
-            echo "[color] section found, checking theme setting..."
             # Check if theme is already set to noctalia under [color]
-            if sed -n '/^\[color\]/,/^\[/p' "$CONFIG_FILE" | grep -q '^theme = "noctalia"'; then
-                echo "Theme already set to noctalia under [color], skipping modification."
-            else
+            if ! sed -n '/^\[color\]/,/^\[/p' "$CONFIG_FILE" | grep -q '^theme = "noctalia"'; then
                 # Check if theme line exists under [color] section
                 if sed -n '/^\[color\]/,/^\[/p' "$CONFIG_FILE" | grep -q '^theme = '; then
                     # Replace existing theme line under [color]
@@ -243,7 +214,6 @@ cava)
                 fi
             fi
         else
-            echo "[color] section not found, adding it with theme..."
             # Add [color] section with theme at the end of file
             echo "" >>"$CONFIG_FILE"
             echo "[color]" >>"$CONFIG_FILE"
@@ -254,19 +224,8 @@ cava)
         # Reload cava if it's running, but only if it's not using stdin config
         if pgrep -f cava >/dev/null; then
             # Check if Cava is running with -p /dev/stdin (managed by CavaService)
-            if pgrep -af cava | grep -q -- "-p.*stdin"; then
-                echo "Cava is managed by CavaService (stdin config), skipping reload signal."
-                echo "✅ Theme file updated. CavaService will use the theme on next restart."
-            else
-                echo "Reloading cava configuration..."
+            if ! pgrep -af cava | grep -q -- "-p.*stdin"; then
                 pkill -USR1 cava
-                echo "✅ Cava reloaded successfully"
-            fi
-        else
-            if [ "$THEME_MODIFIED" = true ]; then
-                echo "✅ Configuration updated. Start cava to see the changes."
-            else
-                echo "✅ Configuration already correct."
             fi
         fi
     else
@@ -276,20 +235,17 @@ cava)
     ;;
 
 yazi)
-    echo "🎨 Applying 'noctalia' flavor to yazi..."
     CONFIG_FILE="$HOME/.config/yazi/theme.toml"
 
     # Create config directory if it doesn't exist
     mkdir -p "$(dirname "$CONFIG_FILE")"
 
     if [ ! -f "$CONFIG_FILE" ]; then
-        echo "Config file not found, creating $CONFIG_FILE..."
         cat >"$CONFIG_FILE" <<'EOF'
 [flavor]
 dark  = "noctalia"
 light = "noctalia"
 EOF
-        echo "Created new theme.toml with noctalia flavor."
     else
         # Check if [flavor] section exists
         if grep -q '^\[flavor\]' "$CONFIG_FILE"; then
@@ -311,37 +267,33 @@ EOF
             echo 'dark  = "noctalia"' >>"$CONFIG_FILE"
             echo 'light = "noctalia"' >>"$CONFIG_FILE"
         fi
-        echo "✅ Updated yazi theme.toml to use noctalia flavor."
     fi
     ;;
 
 niri)
-    echo "🎨 Applying 'noctalia' theme to niri..."
     CONFIG_FILE="$HOME/.config/niri/config.kdl"
     INCLUDE_LINE='include "./noctalia.kdl"'
 
     # Check if the config file exists.
     if [ ! -f "$CONFIG_FILE" ]; then
-        echo "Config file not found, creating $CONFIG_FILE..."
         mkdir -p "$(dirname "$CONFIG_FILE")"
         echo -e "\n$INCLUDE_LINE\n" >"$CONFIG_FILE"
-        echo "Created new config file with noctalia theme."
     else
         # Check if include line already exists
-        if grep -qF "$INCLUDE_LINE" "$CONFIG_FILE"; then
-            echo "Theme already included, skipping modification."
-        else
+        if ! grep -qF "$INCLUDE_LINE" "$CONFIG_FILE"; then
             # Add the include line to the end of the file
             echo -e "\n$INCLUDE_LINE\n" >>"$CONFIG_FILE"
-            echo "✅ Added noctalia theme include to config."
         fi
     fi
     ;;
 
 hyprland)
     echo "🎨 Applying 'noctalia' theme to Hyprland..."
-    CONFIG_FILE="$HOME/.config/hypr/hyprland.conf"
-    INCLUDE_LINE="source = ~/.config/hypr/noctalia/noctalia-colors.conf"
+    CONFIG_DIR="$HOME/.config/hypr"
+    CONFIG_FILE="$CONFIG_DIR/hyprland.conf"
+    THEME_FILE="$CONFIG_DIR/noctalia/noctalia-colors.conf"
+
+    INCLUDE_LINE="source = $THEME_FILE"
 
     # Check if the config file exists.
     if [ ! -f "$CONFIG_FILE" ]; then
@@ -350,6 +302,12 @@ hyprland)
         echo -e "\n$INCLUDE_LINE\n" >"$CONFIG_FILE"
         echo "Created new config file with noctalia theme."
     else
+        if [ -L "$CONFIG_FILE" ] && [ ! -w "$CONFIG_FILE" ]; then
+            echo "Detected read-only symlink, converting to local file..."
+            cp --remove-destination "$(readlink -f "$CONFIG_FILE")" "$CONFIG_FILE"
+            chmod +w "$CONFIG_FILE"
+        fi
+
         # Check if include line already exists
         if grep -qF "$INCLUDE_LINE" "$CONFIG_FILE"; then
             echo "Theme already included, skipping modification."
@@ -361,12 +319,10 @@ hyprland)
     fi
 
     # Reload hyprland
-    echo "✅ Reloading hyprland"
     hyprctl reload
     ;;
 
 mango)
-    echo "🎨 Applying 'noctalia' theme to mango..."
     CONFIG_DIR="$HOME/.config/mango"
     MAIN_CONFIG="$CONFIG_DIR/config.conf"
     THEME_FILE="$CONFIG_DIR/noctalia.conf"
@@ -382,13 +338,11 @@ mango)
 
     # Check if theme is already sourced in main config
     if [ -f "$MAIN_CONFIG" ] && grep -qF "$SOURCE_LINE" "$MAIN_CONFIG"; then
-        echo "Theme already set to noctalia, skipping modification."
+        : # Theme already set
     else
         # First-time setup: backup and remove legacy color definitions
-        echo "Setting up noctalia theme for the first time..."
 
         # Scan all .conf files in config directory for legacy color variables
-        FOUND_LEGACY=false
         for conf_file in "$CONFIG_DIR"/*.conf; do
             # Skip if no .conf files exist or if it's the theme file itself
             [ -e "$conf_file" ] || continue
@@ -396,9 +350,6 @@ mango)
 
             # Check if this file contains any color variable definitions
             if grep -qE "^($COLOR_VARS)\s*=" "$conf_file"; then
-                FOUND_LEGACY=true
-                echo "Found legacy colors in $(basename "$conf_file"), backing up..."
-
                 # Extract and append color definitions to backup file
                 grep -E "^($COLOR_VARS)\s*=" "$conf_file" >>"$BACKUP_FILE"
 
@@ -407,10 +358,6 @@ mango)
             fi
         done
 
-        if [ "$FOUND_LEGACY" = true ]; then
-            echo "✅ Legacy color definitions backed up to $(basename "$BACKUP_FILE")"
-        fi
-
         # Add source line to main config
         if [ -f "$MAIN_CONFIG" ]; then
             echo "" >>"$MAIN_CONFIG"
@@ -420,37 +367,29 @@ mango)
             echo "# This sources the noctalia theme" >"$MAIN_CONFIG"
             echo -e "\n$SOURCE_LINE\n" >>"$MAIN_CONFIG"
         fi
-
-        echo "✅ Added noctalia theme to config."
     fi
 
     # Trigger live reload
     if command -v mmsg >/dev/null 2>&1; then
         mmsg -s -d reload_config
-        echo "✅ Configuration reloaded."
     else
         echo "Warning: mmsg command not found, manual restart may be needed." >&2
     fi
     ;;
 
 btop)
-    echo "🎨 Applying 'noctalia' theme to btop..."
     CONFIG_FILE="$HOME/.config/btop/btop.conf"
 
     if [ -f "$CONFIG_FILE" ]; then
-        if grep -q '^color_theme = "noctalia"' "$CONFIG_FILE"; then
-            echo "Theme already set to noctalia, skipping modification."
-        else
+        if ! grep -q '^color_theme = "noctalia"' "$CONFIG_FILE"; then
             if grep -q '^color_theme = ' "$CONFIG_FILE"; then
                 sed -i 's/^color_theme = .*/color_theme = "noctalia"/' "$CONFIG_FILE"
             else
                 echo 'color_theme = "noctalia"' >>"$CONFIG_FILE"
             fi
-            echo "✅ Updated btop config to use noctalia theme."
         fi
 
         if pgrep -x btop >/dev/null; then
-            echo "Reloading btop..."
             pkill -SIGUSR2 -x btop
         fi
     else
@@ -459,23 +398,21 @@ btop)
     ;;
 
 zathura)
-    echo "🎨 Applying 'noctalia' theme to zathura..."
-
     ZATHURA_INSTANCES=$(dbus-send --session \
-      --dest=org.freedesktop.DBus \
-      --type=method_call \
-      --print-reply \
-      /org/freedesktop/DBus \
-      org.freedesktop.DBus.ListNames \
-      | grep -o 'org.pwmt.zathura.PID-[0-9]*')
+        --dest=org.freedesktop.DBus \
+        --type=method_call \
+        --print-reply \
+        /org/freedesktop/DBus \
+        org.freedesktop.DBus.ListNames |
+        grep -o 'org.pwmt.zathura.PID-[0-9]*')
 
     for id in $ZATHURA_INSTANCES; do
-      dbus-send --session \
-        --dest="$id" \
-        --type=method_call \
-        /org/pwmt/zathura \
-        org.pwmt.zathura.ExecuteCommand \
-        string:"source"
+        dbus-send --session \
+            --dest="$id" \
+            --type=method_call \
+            /org/pwmt/zathura \
+            org.pwmt.zathura.ExecuteCommand \
+            string:"source"
     done
     ;;
 
@@ -485,5 +422,3 @@ zathura)
     exit 1
     ;;
 esac
-
-echo "✅ Command sent for $APP_NAME."
